==> tm_0.2-3.7.tar.gz: tm/man/PlainTextDocument-class.Rd <==
\name{PlainTextDocument-class}
\docType{class}
\alias{PlainTextDocument-class}
\alias{Corpus}
\alias{Corpus<-}
\alias{URI}
\alias{Cached}
\alias{Cached<-}
\alias{Corpus,PlainTextDocument-method}
\alias{Corpus<-,PlainTextDocument-method}
\alias{URI,PlainTextDocument-method}
\alias{Cached,PlainTextDocument-method}
\alias{Cached<-,PlainTextDocument-method}
\title{Text document}
\description{
  A class representing a plain text document with additional information.
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("PlainTextDocument", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{URI}:}{Object of class \code{character} containing
      the path and filename holding the data physically on disk}
    \item{\code{Cached}:}{Object of class \code{numeric} containing the
      status whether the file was already loaded in memory. Zero indicates
      not loaded, a value greater zero indicates in memory.}
  }
}
\section{Extends}{
Class \code{character} and \code{TextDocument}, directly.
}
\section{Methods}{
  \describe{
    \item{Corpus}{\code{signature(object = "PlainTextDocument")}: returns the
      text corpus, i.e., the actual character data slot}
    \item{Corpus<-}{\code{signature(object = "PlainTextDocument")}: sets the
      text corpus, i.e., the actual character data slot}
    \item{URI}{\code{signature(object = "PlainTextDocument")}: returns the
      filename on disk}
    \item{Cached}{\code{signature(object = "PlainTextDocument")}: returns
      status information for loading on demand}
    \item{Cached<-}{\code{signature(object = "PlainTextDocument")}: sets
      status information for loading on demand}
  }
}
\author{Ingo Feinerer}
\keyword{classes}

==> tm_0.3.tar.gz: tm/man/PlainTextDocument-class.Rd <==
\name{PlainTextDocument-class}
\docType{class}
\alias{PlainTextDocument-class}
\alias{Content}
\alias{Content<-}
\alias{URI}
\alias{Cached}
\alias{Cached<-}
\alias{Content,PlainTextDocument-method}
\alias{Content<-,PlainTextDocument-method}
\alias{URI,PlainTextDocument-method}
\alias{Cached,PlainTextDocument-method}
\alias{Cached<-,PlainTextDocument-method}
\title{Text document}
\description{
  A class representing a plain text document with additional information.
}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("PlainTextDocument", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{URI}:}{Object of class \code{character} containing
      the path and filename holding the data physically on disk}
    \item{\code{Cached}:}{Object of class \code{numeric} containing the
      status whether the file was already loaded in memory. Zero indicates
      not loaded, a value greater zero indicates in memory.}
  }
}
\section{Extends}{
Class \code{character} and \code{TextDocument}, directly.
}
\section{Methods}{
  \describe{
    \item{Content}{\code{signature(object = "PlainTextDocument")}: returns the
      text corpus, i.e., the actual character data slot}
    \item{Content<-}{\code{signature(object = "PlainTextDocument")}: sets the
      text corpus, i.e., the actual character data slot}
    \item{URI}{\code{signature(object = "PlainTextDocument")}: returns the
      filename on disk}
    \item{Cached}{\code{signature(object = "PlainTextDocument")}: returns
      status information for loading on demand}
    \item{Cached<-}{\code{signature(object = "PlainTextDocument")}: sets
      status information for loading on demand}
  }
}
\author{Ingo Feinerer}
\keyword{classes}
